<!DOCTYPE TS><TS>
<defaultcodec>iso8859-1</defaultcodec>
<context>
    <name>EditorToolBar</name>
    <message>
        <source>Cut (Ctrl + X)</source>
        <translation type="unfinished">Ausschneiden (Ctrl + X)</translation>
    </message>
    <message>
        <source>Copy (Ctrl + C)</source>
        <translation type="unfinished">Kopieren (Ctrl + C)</translation>
    </message>
    <message>
        <source>Paste (Ctrl + V)</source>
        <translation type="unfinished">Einfügen (Ctrl + V)</translation>
    </message>
    <message>
        <source>Undo (Ctrl + Z)</source>
        <translation type="unfinished">Rückgängig (Ctrl + Z)</translation>
    </message>
    <message>
        <source>Redo (Ctrl + R)</source>
        <translation type="unfinished">Wiederholen (Ctrl + R)</translation>
    </message>
    <message>
        <source>Power (Ctrl + 6)</source>
        <translation type="unfinished">Potenz (Ctrl + 6)</translation>
    </message>
    <message>
        <source>Parentheses (()</source>
        <translation type="unfinished">Klammern (()</translation>
    </message>
    <message>
        <source>Absolute value (|)</source>
        <translation type="unfinished">Absolutbetrag (|)</translation>
    </message>
    <message>
        <source>Fraction (Ctrl + /)</source>
        <translation type="unfinished">Bruch (Ctrl + /)</translation>
    </message>
    <message>
        <source>Root (Ctrl + 2)</source>
        <translation type="unfinished">Wurzel (Ctrl + 2)</translation>
    </message>
</context>
<context>
    <name>G_measureObject</name>
    <message>
        <source>Distance {%1} {%2}</source>
        <translation type="unfinished">Abstand {%1} {%2}</translation>
    </message>
    <message>
        <source>Circumference {%1}</source>
        <translation type="unfinished">Umfang {%1}</translation>
    </message>
    <message>
        <source>Length {%1}</source>
        <translation type="unfinished">Länge {%1}</translation>
    </message>
    <message>
        <source>Radius {%1}</source>
        <translation type="unfinished">Radius {%1}</translation>
    </message>
    <message>
        <source>Arc Angle {%1}</source>
        <translation type="unfinished">Bogenlänge {%1}</translation>
    </message>
    <message>
        <source>Angle {%1}{%2}{%3}</source>
        <translation type="unfinished">Winkel {%1}{%2}{%3}</translation>
    </message>
    <message>
        <source>Ratio {%1}/{%2}</source>
        <translation type="unfinished">Verhältnis {%1}/{%2}</translation>
    </message>
    <message>
        <source>Slope {%1}</source>
        <translation type="unfinished">Steigung {%1}</translation>
    </message>
    <message>
        <source>Area {%1}</source>
        <translation type="unfinished">Fläche {%1}</translation>
    </message>
</context>
<context>
    <name>G_ref</name>
    <message>
        <source>Point</source>
        <translation type="unfinished">Punkt</translation>
    </message>
    <message>
        <source>Segment</source>
        <translation type="unfinished">Strecke</translation>
    </message>
    <message>
        <source>Ray</source>
        <translation type="unfinished">Halbgerade</translation>
    </message>
    <message>
        <source>Line</source>
        <translation type="unfinished">Gerade</translation>
    </message>
    <message>
        <source>Circle</source>
        <translation type="unfinished">Kreis</translation>
    </message>
    <message>
        <source>Arc</source>
        <translation type="unfinished">Kreisbogen</translation>
    </message>
    <message>
        <source>Polygon</source>
        <translation type="unfinished">Vieleck</translation>
    </message>
    <message>
        <source>Circle Interior</source>
        <translation type="unfinished">Kreisinneres</translation>
    </message>
    <message>
        <source>Arc Sector</source>
        <translation type="unfinished">Kreisringsektor</translation>
    </message>
    <message>
        <source>Arc Segment</source>
        <translation type="unfinished">Kreissegment</translation>
    </message>
    <message>
        <source>Locus</source>
        <translation type="unfinished">Ortslinie</translation>
    </message>
    <message>
        <source>Measurement</source>
        <translation type="unfinished">Messung</translation>
    </message>
    <message>
        <source>Calculation</source>
        <translation type="unfinished">Berechnung</translation>
    </message>
    <message>
        <source>Annotation</source>
        <translation type="unfinished">Anmerkung</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished">Unbekannt</translation>
    </message>
</context>
<context>
    <name>G_valueObject</name>
    <message>
        <source>undefined</source>
        <translation type="unfinished">undefiniert</translation>
    </message>
</context>
<context>
    <name>KSegCalculateEditor</name>
    <message>
        <source>Value is undefined</source>
        <translation type="unfinished">Wert nicht definiert</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Abbruch</translation>
    </message>
    <message>
        <source>Value is %1</source>
        <translation type="unfinished">Wert ist %1</translation>
    </message>
    <message>
        <source>Insert %1 %2</source>
        <comment>For example, &quot;Insert Measurement M1&quot;</comment>
        <translation type="unfinished">Einfügen von %1 %2</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation type="unfinished">Bereit</translation>
    </message>
</context>
<context>
    <name>KSegConstructionList</name>
    <message>
        <source>Loop on %1</source>
        <translation type="unfinished">Rekursion auf %1</translation>
    </message>
    <message>
        <source>or</source>
        <translation type="unfinished">oder</translation>
    </message>
    <message>
        <source>final</source>
        <translation type="unfinished">endgültig</translation>
    </message>
    <message>
        <source>initial</source>
        <translation type="unfinished">unabhängig</translation>
    </message>
    <message>
        <source>not constructed</source>
        <translation type="unfinished">nicht konstruiert</translation>
    </message>
    <message>
        <source>doesn&apos;t exist</source>
        <translation type="unfinished">existiert nicht</translation>
    </message>
    <message>
        <source>hidden</source>
        <translation type="unfinished">versteckt</translation>
    </message>
    <message>
        <source>Given</source>
        <translation type="unfinished">Gegeben</translation>
    </message>
    <message>
        <source>Final</source>
        <translation type="unfinished">Endgültig</translation>
    </message>
    <message>
        <source>Initial</source>
        <translation type="unfinished">Unabhängig</translation>
    </message>
    <message>
        <source>%1 is the translation of %2 by the vector from %3 to %4</source>
        <translation>%1 ist %2 verschoben um den Vektor  von %3 nach %4</translation>
    </message>
    <message>
        <source>%1 is the rotation of %2 about %3 by angle %4</source>
        <translation type="unfinished">%1 ist %2 nach einer Drehung mit Zentrum %3 und Drehwinkel %4.</translation>
    </message>
    <message>
        <source>%1 is the image of %2 scaled about %3 by the ratio %4:%5</source>
        <translation type="unfinished">%1 ist das Bild von %2 unter der Streckung mit Zentrum %3 und Verhältnis %4:%5</translation>
    </message>
    <message>
        <source>%1 is the image of %2 scaled about %3 by ratio %4</source>
        <translation type="unfinished">%1 ist das Bild von %2 unter der Streckung mit Zentrum %3 und Verhältnis %4:%5</translation>
    </message>
    <message>
        <source>%1 is the reflection of %2 about %3</source>
        <translation type="unfinished">%1 ist das Bild von %2 gespiegelt an %3</translation>
    </message>
    <message>
        <source>%1 is free</source>
        <translation type="unfinished">%1 ist frei</translation>
    </message>
    <message>
        <source>%1 is on %2</source>
        <translation type="unfinished">%1 liegt auf %2</translation>
    </message>
    <message>
        <source>%1 is the intersection of %2 and %3</source>
        <translation type="unfinished">%1 ist der Schnittpunkt von %2 und %3</translation>
    </message>
    <message>
        <source>%1 is the 2nd intersection of %2 and %3</source>
        <translation type="unfinished">%1 ist der zweite Schnittpunkt von %2 und %3</translation>
    </message>
    <message>
        <source>%1 is the midpoint of %2</source>
        <translation type="unfinished">%1 ist der Mittelpunkt von %2</translation>
    </message>
    <message>
        <source>%1 has endpoints %2 and %3</source>
        <translation>%1 hat die Endpunkte %2 und %3</translation>
    </message>
    <message>
        <source>%1 is from %2 through %3</source>
        <translation type="unfinished">%1 geht von %2 durch %3</translation>
    </message>
    <message>
        <source>%1 bisects angle %2 %3 %4</source>
        <translation type="unfinished">%1 halbiert den Winkel %2 %3 %4</translation>
    </message>
    <message>
        <source>%1 is between %2 and %3</source>
        <translation type="unfinished">%1 liegt zwischen %2 und %3</translation>
    </message>
    <message>
        <source>%1 is parallel to %2 through %3</source>
        <translation type="unfinished">%1 ist parallel zu %2 und geht durch %3</translation>
    </message>
    <message>
        <source>%1 is perpendicular to %2 through %3</source>
        <translation type="unfinished">%1 ist senkrecht zu %2 und geht durch %3</translation>
    </message>
    <message>
        <source>%1 is centered at %2 and passes through %3</source>
        <translation type="unfinished">%1 hat den Mittelpunkt %2 und den Randpunkt %3</translation>
    </message>
    <message>
        <source>%1 has center at %2 and radius %3</source>
        <translation type="unfinished">%1 hat  Mittelpunkt %2 und Radius %3</translation>
    </message>
    <message>
        <source>%1 passes through points %2, %3, and %4</source>
        <translation type="unfinished">%1 geht durch die Punkte %2, %3 und %4</translation>
    </message>
    <message>
        <source>%1 is traced by %2, driven by %3</source>
        <translation type="unfinished">%1 beschreibt den Weg von %2 in Abhängigkeit von %3</translation>
    </message>
    <message>
        <source>%1 involves %2</source>
        <translation>%1 bezieht %2 ein</translation>
    </message>
    <message>
        <source>%1 is the distance between %2 and %3</source>
        <translation type="unfinished">%1 ist die Entfernung zwischen %2 und %3</translation>
    </message>
    <message>
        <source>%1 is the length of %2</source>
        <translation type="unfinished">%1 ist die Länge von  %2</translation>
    </message>
    <message>
        <source>%1 is the angle of %2</source>
        <translation type="unfinished">%1 ist der Winkel von  %2</translation>
    </message>
    <message>
        <source>%1 is the angle between points %1, %2, and %3</source>
        <translation type="unfinished">%1 ist der Winkel zwischen  %1, %2 und  %3</translation>
    </message>
    <message>
        <source>%1 is the ratio of %2 to %3</source>
        <translation type="unfinished">%1 ist das Verhältnis von %2 zu %3</translation>
    </message>
    <message>
        <source>%1 is the slope of %2</source>
        <translation type="unfinished">%1 ist die Steigung von  %2</translation>
    </message>
    <message>
        <source>%1 is the area of %2</source>
        <translation type="unfinished">%1 ist die Fläche von %2</translation>
    </message>
    <message>
        <source>%1 is defined by %2</source>
        <translation type="unfinished">%1 ist definiert durch %2</translation>
    </message>
    <message>
        <source>%1 has vertices at points %2</source>
        <translation type="unfinished">%1 hat die Scheitelpunkte %2</translation>
    </message>
    <message>
        <source>%1 is the radius of %2</source>
        <translation type="unfinished">%1 ist der Radius von %2</translation>
    </message>
    <message>
        <source>%1 is the endpoint of %2</source>
        <translation type="unfinished">%1 ist der Endpunkt von %2</translation>
    </message>
    <message>
        <source>%1 is the 2nd endpoint of %2</source>
        <translation type="unfinished">%1 ist der zweite Enpunkt von %2</translation>
    </message>
    <message>
        <source>%1 is the center of %2</source>
        <translation type="unfinished">%1 ist der Mittelpunkt von %2</translation>
    </message>
</context>
<context>
    <name>KSegDocument</name>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Abbruch</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
</context>
<context>
    <name>KSegPreferencesDialog</name>
    <message>
        <source>KSEG Preferences</source>
        <translation type="unfinished">KSEG Einstellungen</translation>
    </message>
    <message>
        <source>Background Color</source>
        <translation type="unfinished">Hintergrundfarbe</translation>
    </message>
    <message>
        <source>Default Foreground Color</source>
        <translation type="unfinished">Voreingestellte Vordergrundfarbe</translation>
    </message>
    <message>
        <source>Selection Display</source>
        <translation type="unfinished">Auswahlanzeige</translation>
    </message>
    <message>
        <source>Border Selection</source>
        <translation type="unfinished">Randauswahl</translation>
    </message>
    <message>
        <source>Blinking Selection</source>
        <translation type="unfinished">Blinkende Auswahl</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Abbruch</translation>
    </message>
</context>
<context>
    <name>KSegRecursionDialog</name>
    <message>
        <source>Enter recursion depth:</source>
        <translation type="unfinished">Anzahl der Rekursionen:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Abbruch</translation>
    </message>
    <message>
        <source>Will produce too many objects.</source>
        <translation type="unfinished">Das würde zu viele Objekte ergeben!</translation>
    </message>
    <message>
        <source>Will produce %1 objects.</source>
        <translation type="unfinished">Es entstehen %1 objekte.</translation>
    </message>
</context>
<context>
    <name>KSegSampleChangeDialog</name>
    <message>
        <source>Samples in locus:</source>
        <translation type="unfinished">Zahl der Punkte auf der Ortslinie:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Abbruch</translation>
    </message>
</context>
<context>
    <name>KSegSelectionGroupDialog</name>
    <message>
        <source>Select</source>
        <translation type="unfinished">Auswählen</translation>
    </message>
    <message>
        <source>Deselect</source>
        <translation type="unfinished">Auswahl aufheben</translation>
    </message>
    <message>
        <source>New Group</source>
        <translation type="unfinished">Neue Gruppe</translation>
    </message>
    <message>
        <source>Delete Group</source>
        <translation type="unfinished">Gruppe löschen</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished">Schließen</translation>
    </message>
    <message>
        <source>Affect
Invisible
Items</source>
        <translation type="unfinished">Unsichtbare Elemente werden einbezogen</translation>
    </message>
    <message>
        <source>Hold SHIFT and click to add to current selection</source>
        <translation type="unfinished">Verwende SHIFT-Klick, um Elemente zur aktuellen Auswahl hinzuzufügen</translation>
    </message>
    <message>
        <source>Whether the &quot;All &lt;Type&gt;&quot; groups also (de)select invisible objects</source>
        <translation type="unfinished">Die Auswahl von &quot;Alle &lt;Typ&quot; betrifft auch unsichtbare Objekte</translation>
    </message>
    <message>
        <source>All Points</source>
        <translation type="unfinished">Alle Punkte</translation>
    </message>
    <message>
        <source>All Segments</source>
        <translation type="unfinished">Alle Strecken</translation>
    </message>
    <message>
        <source>All Rays</source>
        <translation type="unfinished">Alle Halbgeraden</translation>
    </message>
    <message>
        <source>All Lines</source>
        <translation type="unfinished">Alle Geraden</translation>
    </message>
    <message>
        <source>All Circles</source>
        <translation type="unfinished">Alle Kreise</translation>
    </message>
    <message>
        <source>All Arcs</source>
        <translation type="unfinished">Alle Kreisbögen</translation>
    </message>
    <message>
        <source>All Polygons</source>
        <translation type="unfinished">Alle Polygone</translation>
    </message>
    <message>
        <source>All Circle Interiors</source>
        <translation type="unfinished">Alle Kreisinneren</translation>
    </message>
    <message>
        <source>All Arc Sectors</source>
        <translation type="unfinished">Alle Kreisringsektoren</translation>
    </message>
    <message>
        <source>All Arc Segments</source>
        <translation type="unfinished">Alle Kreissegmente</translation>
    </message>
    <message>
        <source>All Loci</source>
        <translation type="unfinished">Alle Ortslinien</translation>
    </message>
    <message>
        <source>All Measurements</source>
        <translation type="unfinished">Alle Messungen</translation>
    </message>
    <message>
        <source>All Calculations</source>
        <translation type="unfinished">Alle Berechnungen</translation>
    </message>
    <message>
        <source>Enter new group name:</source>
        <translation type="unfinished">Geben Sie einen neuen Gruppennamen ein:</translation>
    </message>
    <message>
        <source>Are you sure you want to delete the selected group(s)?</source>
        <translation type="unfinished">Möchten Sie wirklich die ausgewählten Gruppe(n) löschen?</translation>
    </message>
</context>
<context>
    <name>KSegView</name>
    <message>
        <source>Untitled</source>
        <translation type="unfinished">Unbenannt</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation type="unfinished">Bereit</translation>
    </message>
    <message>
        <source>Move label of %1 %2</source>
        <comment>E.g. &quot;Move label of Point P1&quot;</comment>
        <translation type="unfinished">Verschiebe Label von %1 %2</translation>
    </message>
    <message>
        <source>Select %1 %2</source>
        <translation type="unfinished">Auswahl von %1 %2</translation>
    </message>
    <message>
        <source>Deselect %1 %2</source>
        <translation type="unfinished">Auswahl von %1 %2 aufheben</translation>
    </message>
    <message>
        <source>Also select %1 %2</source>
        <translation type="unfinished">%1 %2 zusätzlich auswählen</translation>
    </message>
    <message>
        <source>Move Selected Objects</source>
        <translation type="unfinished">Ausgewählte Objekte bewegen</translation>
    </message>
    <message>
        <source>Reconstrain %1 %2 to be free</source>
        <translation type="unfinished">%1 %2 als frei redefinieren</translation>
    </message>
    <message>
        <source>Reconstrain %1 %2 to %3 %4</source>
        <comment>E.g., &quot;Reconstrain Point P1 to Line l1&quot;</comment>
        <translation type="unfinished">Anbinden von %1 %2 an %3 %4</translation>
    </message>
    <message>
        <source>Reconstrain %1 %2 to the intersection of %3 %4 and %5 %6</source>
        <translation type="unfinished">Anbinden von  %1 %2 an den Schnitt von %3 %4 und %5 %6</translation>
    </message>
    <message>
        <source>Pan</source>
        <translation type="unfinished">Verschieben</translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation type="unfinished">Vergrößern/Verkleinern</translation>
    </message>
</context>
<context>
    <name>KSegWindow</name>
    <message>
        <source>kseg: Untitled</source>
        <translation type="unfinished">kseg: Unbenannt</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished">Datei (&amp;F)</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished">B&amp;earbeiten</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished">&amp;Neu</translation>
    </message>
    <message>
        <source>Meas&amp;ure</source>
        <translation type="unfinished">Mess&amp;ung</translation>
    </message>
    <message>
        <source>&amp;Transform</source>
        <translation type="unfinished">Abbilden (&amp;T)</translation>
    </message>
    <message>
        <source>Pla&amp;y</source>
        <translation type="unfinished">Konstruktionen (&amp;y)</translation>
    </message>
    <message>
        <source>Const&amp;ruction</source>
        <translation type="unfinished">Konst&amp;ruktion</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished">&amp;Hilfe</translation>
    </message>
    <message>
        <source>&amp;New Sketch</source>
        <translation type="unfinished">&amp;Neue Skizze</translation>
    </message>
    <message>
        <source>Ne&amp;w Construction</source>
        <translation type="unfinished">Neue Konstruktion (&amp;w)</translation>
    </message>
    <message>
        <source>New &amp;View</source>
        <translation type="unfinished">Neue Ansicht (&amp;V)</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation type="unfinished">&amp;Oeffnen...</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation type="unfinished">&amp;Speichern</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation type="unfinished">Speichern &amp;Als...</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation type="unfinished">Drucken ... (&amp;P)</translation>
    </message>
    <message>
        <source>Choose &amp;Language...</source>
        <translation type="unfinished">Sprache auswählen (&amp;L)...</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished">S&amp;chließen</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation type="unfinished">Beenden (&amp;Q)</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation type="unfinished">R&amp;ueckgängig</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation type="unfinished">Wiederholen (&amp;R)</translation>
    </message>
    <message>
        <source>&amp;Delete Objects</source>
        <translation type="unfinished">Objekte löschen (&amp;D)</translation>
    </message>
    <message>
        <source>Toggle &amp;Label</source>
        <translation type="unfinished">&amp;Label an / aus</translation>
    </message>
    <message>
        <source>Hide Label</source>
        <translation type="unfinished">Label verstecken</translation>
    </message>
    <message>
        <source>Show Label</source>
        <translation type="unfinished">Label zeigen</translation>
    </message>
    <message>
        <source>Change La&amp;bel...</source>
        <translation type="unfinished">La&amp;bel ändern</translation>
    </message>
    <message>
        <source>&amp;Hide Objects</source>
        <translation type="unfinished">Objekte verstecken (&amp;H)</translation>
    </message>
    <message>
        <source>&amp;Unhide All</source>
        <translation type="unfinished">Alles Zeigen (&amp;U)</translation>
    </message>
    <message>
        <source>&amp;Color</source>
        <translation type="unfinished">Farbe (&amp;C)</translation>
    </message>
    <message>
        <source>Line &amp;Style</source>
        <translation type="unfinished">Linien-&amp;Stil</translation>
    </message>
    <message>
        <source>&amp;Point Style</source>
        <translation type="unfinished">&amp;Punkt-Stil</translation>
    </message>
    <message>
        <source>&amp;Font</source>
        <translation type="unfinished">Zeichensatz (&amp;F)</translation>
    </message>
    <message>
        <source>Change &amp;Number of Samples...</source>
        <translation type="unfinished">A&amp;nzahl der Ortslinienpunkte ändern...</translation>
    </message>
    <message>
        <source>&amp;Other...</source>
        <translation type="unfinished">&amp;Andere</translation>
    </message>
    <message>
        <source>&amp;Font...</source>
        <translation type="unfinished">&amp;Zeichensatz...</translation>
    </message>
    <message>
        <source>&amp;Intersection Point</source>
        <translation type="unfinished">Schn&amp;ittpunkt</translation>
    </message>
    <message>
        <source>&amp;Segment</source>
        <translation type="unfinished">&amp;Strecke</translation>
    </message>
    <message>
        <source>&amp;Midpoint</source>
        <translation type="unfinished">&amp;Mittelpunkt</translation>
    </message>
    <message>
        <source>&amp;Ray</source>
        <translation type="unfinished">Halbge&amp;rade</translation>
    </message>
    <message>
        <source>&amp;Line</source>
        <translation type="unfinished">Gerade (&amp;L)</translation>
    </message>
    <message>
        <source>&amp;Perpendicular Line</source>
        <translation type="unfinished">Lotgerade (&amp;P)</translation>
    </message>
    <message>
        <source>&amp;Circle By Center And Point</source>
        <translation type="unfinished">Kreis (geg. Mittelpunkt und Randpunkt) &amp;C</translation>
    </message>
    <message>
        <source>&amp;Arc By Three Points</source>
        <translation type="unfinished">Kreisbogen durch drei Punkte</translation>
    </message>
    <message>
        <source>Angle &amp;Bisector</source>
        <translation type="unfinished">Winkelhalbierende (&amp;B)</translation>
    </message>
    <message>
        <source>L&amp;ocus</source>
        <translation type="unfinished">&amp;Ortslinie</translation>
    </message>
    <message>
        <source>Poly&amp;gon</source>
        <translation type="unfinished">Vieleck (&amp;g)</translation>
    </message>
    <message>
        <source>Arc S&amp;ector</source>
        <translation type="unfinished">Kreisrings&amp;ektor</translation>
    </message>
    <message>
        <source>Arc Se&amp;gment</source>
        <translation type="unfinished">Kreisse&amp;gment</translation>
    </message>
    <message>
        <source>Circle I&amp;nterior</source>
        <translation type="unfinished">Kreisi&amp;nneres</translation>
    </message>
    <message>
        <source>&amp;Distance</source>
        <translation type="unfinished">Entfernung (&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Length</source>
        <translation type="unfinished">&amp;Länge</translation>
    </message>
    <message>
        <source>&amp;Radius</source>
        <translation type="unfinished">&amp;Radius</translation>
    </message>
    <message>
        <source>&amp;Angle</source>
        <translation type="unfinished">Winkel (&amp;W)</translation>
    </message>
    <message>
        <source>Ra&amp;tio</source>
        <translation type="unfinished">Verhäl&amp;tnis</translation>
    </message>
    <message>
        <source>&amp;Slope</source>
        <translation type="unfinished">&amp;Steigung</translation>
    </message>
    <message>
        <source>Ar&amp;ea</source>
        <translation type="unfinished">Fläche (&amp;e)</translation>
    </message>
    <message>
        <source>&amp;Calculate...</source>
        <translation type="unfinished">Bere&amp;chne...</translation>
    </message>
    <message>
        <source>Choose &amp;Vector</source>
        <translation type="unfinished">&amp;Vector auswählen</translation>
    </message>
    <message>
        <source>Choose &amp;Mirror</source>
        <translation type="unfinished">Spiegelgerade auswählen (&amp;M)</translation>
    </message>
    <message>
        <source>Choose &amp;Center</source>
        <translation type="unfinished">Zentrum auswählen (&amp;C)</translation>
    </message>
    <message>
        <source>Choose &amp;Angle</source>
        <translation type="unfinished">Winkel &amp;auswählen</translation>
    </message>
    <message>
        <source>Choose Rati&amp;o</source>
        <translation type="unfinished">Verhältnis auswählen (&amp;o)</translation>
    </message>
    <message>
        <source>C&amp;lear Chosen</source>
        <translation type="unfinished">Auswahl löschen</translation>
    </message>
    <message>
        <source>&amp;Translate</source>
        <translation type="unfinished">Verschieben (&amp;T)</translation>
    </message>
    <message>
        <source>R&amp;eflect</source>
        <translation type="unfinished">Spi&amp;egeln</translation>
    </message>
    <message>
        <source>&amp;Scale</source>
        <translation type="unfinished">&amp;Strecken</translation>
    </message>
    <message>
        <source>&amp;Rotate</source>
        <translation type="unfinished">D&amp;rehen</translation>
    </message>
    <message>
        <source>Make &amp;Normal</source>
        <translation type="unfinished">Definiere als &amp;normal</translation>
    </message>
    <message>
        <source>Make &amp;Given</source>
        <translation type="unfinished">Definiere als &amp;gegeben</translation>
    </message>
    <message>
        <source>Make &amp;Final</source>
        <translation type="unfinished">Definiere als &amp;final</translation>
    </message>
    <message>
        <source>Make &amp;Initial</source>
        <translation type="unfinished">Definiere als konstant (&amp;I)</translation>
    </message>
    <message>
        <source>&amp;Recurse</source>
        <translation type="unfinished">&amp;Rekursion</translation>
    </message>
    <message>
        <source>&amp;Quick Play</source>
        <translation type="unfinished">&amp;Schnellauswahl (&amp;Q)</translation>
    </message>
    <message>
        <source>&amp;About...</source>
        <translation type="unfinished">Über...</translation>
    </message>
    <message>
        <source>&amp;Circumference</source>
        <translation type="unfinished">Umfang (&amp;C)</translation>
    </message>
    <message>
        <source>Arc &amp;Length</source>
        <translation type="unfinished">Bogen&amp;länge</translation>
    </message>
    <message>
        <source>Toggle &amp;Labels</source>
        <translation type="unfinished">&amp;Labels an/aus</translation>
    </message>
    <message>
        <source>Hide Labels</source>
        <translation type="unfinished">Labels verstecken</translation>
    </message>
    <message>
        <source>Show Labels</source>
        <translation type="unfinished">Labels zeigen</translation>
    </message>
    <message>
        <source>&amp;Segments</source>
        <translation type="unfinished">Strecken</translation>
    </message>
    <message>
        <source>&amp;Rays</source>
        <translation type="unfinished">Halbgeraden</translation>
    </message>
    <message>
        <source>&amp;Midpoints</source>
        <translation type="unfinished">Mittelpunkte</translation>
    </message>
    <message>
        <source>&amp;Intersection Points</source>
        <translation type="unfinished">Schnittpunkte</translation>
    </message>
    <message>
        <source>&amp;Circle By Center And Radius</source>
        <translation type="unfinished">Kreis (Mittelpunkt und Radius)</translation>
    </message>
    <message>
        <source>&amp;Lines</source>
        <translation type="unfinished">Geraden</translation>
    </message>
    <message>
        <source>Parallel &amp;Lines</source>
        <translation type="unfinished">Parallele Geraden</translation>
    </message>
    <message>
        <source>Parallel &amp;Line</source>
        <translation type="unfinished">Parallele Gerade</translation>
    </message>
    <message>
        <source>&amp;Perpendicular Lines</source>
        <translation type="unfinished">Senkrechte Geraden</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation type="unfinished">Unbenannt</translation>
    </message>
    <message>
        <source>&amp;Change Directory...</source>
        <translation type="unfinished">Anderes Verzeichnis... (&amp;C)</translation>
    </message>
    <message>
        <source>No Constructions</source>
        <translation type="unfinished">Keine Konstruktionen</translation>
    </message>
    <message>
        <source>Save?</source>
        <translation type="unfinished">Speichern?</translation>
    </message>
    <message>
        <source>Would you like to save your changes?</source>
        <translation type="unfinished">Möchten Sie Ihre Änderungen speichern?</translation>
    </message>
    <message>
        <source>File Not Found</source>
        <translation type="unfinished">Datei nicht gefunden</translation>
    </message>
    <message>
        <source>Sorry, I am afraid that file %1 does not exist.</source>
        <translation type="unfinished">Die Datei  %1 existiert leider nicht.</translation>
    </message>
    <message>
        <source>Invalid file</source>
        <translation type="unfinished">Ungültige Datei</translation>
    </message>
    <message>
        <source>The file %1 does not look like a valid KSEG file.</source>
        <translation type="unfinished">Die Datei %1 scheint keine gültige KSEG -Datei zu sein.</translation>
    </message>
    <message>
        <source>Language Change</source>
        <translation type="unfinished">Sprache ändern</translation>
    </message>
    <message>
        <source>You will need to restart KSEG for the language change to fully take effect.</source>
        <translation type="unfinished">Um die Sprache vollständig umzustellen müssen sie KSEG neu starten!</translation>
    </message>
    <message>
        <source>About KSEG</source>
        <translation type="unfinished">Über KSEG</translation>
    </message>
    <message>
        <source>&amp;Delete Object</source>
        <translation type="unfinished">Objekt löschen (&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Hide Object</source>
        <translation type="unfinished">Objekt verstecken (&amp;H)</translation>
    </message>
    <message>
        <source>Pr&amp;eferences...</source>
        <translation type="unfinished">&amp;Einstellungen</translation>
    </message>
    <message>
        <source>KSEG v%1
Copyright (C) %2 Ilya Baran
http://www.mit.edu/~ibaran
ibaran@mit.edu</source>
        <translation type="unfinished">KSEG v%1
Copyright (C) %2 Ilya Baran
http://www.mit.edu/~ibaran
ibaran@mit.edu</translation>
    </message>
    <message>
        <source>Open In Current Window...</source>
        <translation type="unfinished">Im aktuellen Fenster öffnen</translation>
    </message>
    <message>
        <source>Copy As Construction</source>
        <translation type="unfinished">Als Konstruktion öffnen</translation>
    </message>
    <message>
        <source>Selection &amp;Groups...</source>
        <translation type="unfinished">Auswahl und Gruppen</translation>
    </message>
    <message>
        <source>&amp;Zoom</source>
        <translation type="unfinished">Vergrößern (&amp;Z)</translation>
    </message>
    <message>
        <source>&amp;Pan</source>
        <translation type="unfinished">Skizze Verschieben (&amp;P)</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation type="unfinished">Ansicht (&amp;V)</translation>
    </message>
    <message>
        <source>Zoom To &amp;Fit</source>
        <translation type="unfinished">Größe an &amp;Fenster anpassen</translation>
    </message>
    <message>
        <source>&amp;Original Zoom (100%)</source>
        <translation type="unfinished">&amp;Originalgröße</translation>
    </message>
    <message>
        <source>E&amp;xport To Image...</source>
        <translation type="unfinished">Grafik-E&amp;xport</translation>
    </message>
    <message>
        <source>Endpoints</source>
        <translation type="unfinished">Endpunkte</translation>
    </message>
    <message>
        <source>Center Point</source>
        <translation type="unfinished">Mittelpunkt</translation>
    </message>
    <message>
        <source>Endpoint</source>
        <translation type="unfinished">Endpunkt</translation>
    </message>
    <message>
        <source>Zoom:</source>
        <translation type="unfinished">Vergrößerung:</translation>
    </message>
    <message>
        <source>Choose the File Format:</source>
        <translation type="unfinished">Dateiformat auswählen:</translation>
    </message>
    <message>
        <source>High Quality Image</source>
        <translation type="unfinished">Hohe Bildqualität</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <source>Exporting, Please wait...</source>
        <translation type="unfinished">Bitte warten Sie während des Exportvorganges</translation>
    </message>
</context>
<context>
    <name>MatrixDialog</name>
    <message>
        <source>Rows:</source>
        <translation type="unfinished">Zeilen:</translation>
    </message>
    <message>
        <source>Columns:</source>
        <translation type="unfinished">Spalten:</translation>
    </message>
    <message>
        <source>Zero-Fill</source>
        <translation type="unfinished">Mit Nullen füllen</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Abbruch</translation>
    </message>
</context>
</TS>
